@@ -1,6 +1,7 @@
+from itertools import product
 import os
 import sys
-from typing import Dict, Iterable, List
+from typing import Any, Dict, Iterable, List
 
 import pluggy
 from tox.config import Config, _split_env as split_env
@@ -20,7 +21,7 @@ def tox_configure(config):
     version = get_python_version()
     verbosity2("Python version: {}".format(version))
 
-    gh_actions_config = parse_config(config._cfg.sections.get("gh-actions", {}))
+    gh_actions_config = parse_config(config._cfg.sections)
     verbosity2("tox-gh-actions config: {}".format(gh_actions_config))
 
     factors = get_factors(gh_actions_config, version)
@@ -35,20 +36,33 @@ def tox_configure(config):
 
 
 def parse_config(config):
-    # type: (Dict[str, str]) -> Dict[str, Dict[str, List[str]]]
+    # type: (Dict[str, Dict[str, str]]) -> Dict[str, Dict[str, Any]]
     """Parse gh-actions section in tox.ini"""
-    config_python = parse_dict(config.get("python", ""))
+    config_python = parse_dict(config.get("gh-actions", {}).get("python", ""))
+    config_env = {
+        name: {k: split_env(v) for k, v in parse_dict(conf).items()}
+        for name, conf in config.get("gh-actions:env", {}).items()
+    }
     # Example of split_env:
     # "py{27,38}" => ["py27", "py38"]
     return {
-        "python": {k: split_env(v) for k, v in config_python.items()}
+        "python": {k: split_env(v) for k, v in config_python.items()},
+        "env": config_env,
     }
 
 
 def get_factors(gh_actions_config, version):
-    # type: (Dict[str, Dict[str, List[str]]], str) -> List[str]
+    # type: (Dict[str, Dict[str, Any]], str) -> List[str]
     """Get a list of factors"""
-    return gh_actions_config["python"].get(version, [])
+    factors = []  # type: List[List[str]]
+    if version in gh_actions_config["python"]:
+        factors.append(gh_actions_config["python"][version])
+    for env, env_config in gh_actions_config.get("env", {}).items():
+        if env in os.environ:
+            env_value = os.environ[env]
+            if env_value in env_config:
+                factors.append(env_config[env_value])
+    return [x for x in map(lambda f: "-".join(f), product(*factors)) if x]
 
 
 def get_envlist_from_factors(envlist, factors):
